/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests.compatibility;

import static org.thermostat.qa2.framework.Assert.*;
import org.thermostat.qa2.framework.annotations.SetupStorage;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.annotations.ThermostatSetupTarget;
import org.thermostat.qa2.framework.services.ThermostatAgent;
import org.thermostat.qa2.framework.services.ThermostatStorage;

/**
 *
 * @author Zdeněk Žamberský
 */
// setup "mongo" storage for "other" thermostat before every test
@SetupStorage(type = "mongo")
@ThermostatSetupTarget("other")
public class DBCompatibilityTest {

    @Test
    public void simpleStorageTest() throws Exception {
        // "other" thermostat
        ThermostatStorage thermostatOtherStorage = new ThermostatStorage("other");
        thermostatOtherStorage.start();
        Thread.sleep(5000);
        thermostatOtherStorage.stop();

        // "tested" thermostat
        ThermostatStorage thermostatStorage = new ThermostatStorage("tested");
        thermostatStorage.start(); // if it fails to start it throws exception
        // thermostatStorage is stopped automatically by framework       
    }

    @Test
    public void simpleStorageAgentTest() throws Exception {
        // "other" thermostat
        ThermostatStorage thermostatOtherStorage = new ThermostatStorage("other");
        ThermostatAgent thermostatOtherAgent = new ThermostatAgent("other");
        thermostatOtherStorage.start();
        thermostatOtherAgent.start();
        Thread.sleep(10000);
        assertTrue(thermostatOtherAgent.isRunning(), "Agent should be running");
        thermostatOtherAgent.stop();
        thermostatOtherStorage.stop();

        // "tested" thermostat
        ThermostatStorage thermostatStorage = new ThermostatStorage("tested");
        ThermostatAgent thermostatAgent = new ThermostatAgent("tested");
        thermostatStorage.start();
        thermostatAgent.start();
        Thread.sleep(10000);
        assertTrue(thermostatAgent.isRunning(), "Agent should be running");
        // thermostat storage and agent are stopped automatically by framework       
    }

}
